@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of logilab-common.
@@ -75,7 +75,7 @@ class LazyObject(object):
         self.obj = obj
         self._imported = None
 
-    def __getobj(self):
+    def _getobj(self):
         if self._imported is None:
            self._imported = getattr(load_module_from_name(self.module),
                                     self.obj)
@@ -85,10 +85,10 @@ class LazyObject(object):
         try:
             return super(LazyObject, self).__getattribute__(attr)
         except AttributeError, ex:
-            return getattr(self.__getobj(), attr)
+            return getattr(self._getobj(), attr)
 
     def __call__(self, *args, **kwargs):
-        return self.__getobj()(*args, **kwargs)
+        return self._getobj()(*args, **kwargs)
 
 
 def load_module_from_name(dotted_name, path=None, use_sys=1):
